from django.apps import AppConfig
from django.conf import settings

import django_better_migrations.rules as rules


class MigrationsConfig(AppConfig):
    name = "django_better_migrations"

    def ready(self):
        """
        This method allows importing our patches only once the django app is loaded.
        See docs: https://docs.djangoproject.com/en/dev/ref/applications/#django.apps.AppConfig.ready
        """
        import django_better_migrations.migration_writer_patch  # noqa


DEFAULT_CONFIGURATION = {
    "RULES": [
        rules.NoAddColumnNonNull,
    ],
    "ALLOW_ENGINES": [],
}


def get_setting(key):
    app_setting = getattr(settings, "BETTER_MIGRATIONS", {})

    if key in app_setting:
        return app_setting[key]

    return DEFAULT_CONFIGURATION[key]



from setuptools import setup, find_packages

version = __import__("django_better_migrations").__version__


def read(path):
    """Return the content of a file."""
    with open(path, "r") as f:
        return f.read()


setup(
    name="django-better-migrations",
    version=version,
    description="Improves Django migration system.",
    long_description=(read("README.md")),
    url="http://github.com/botify-labs/django-better-migrations",
    license="MIT",
    author="Jean-Baptiste Barth",
    author_email="jeanbaptiste.barth@gmail.com",
    packages=find_packages(exclude=["tests*"]),
    scripts=[],
    install_requires=[],
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX",
        "Programming Language :: Python",
        "Topic :: Database",
    ],
)
